% Example name: One-way2SamplesGroupwiseStochastic
% Description: this script creates 2 samples of 100 words each from the MRC database file ('MRC.txt')
% The 2 samples will be different on 1 dimension ('KFfrequency'), p-value < .05, and matched on 3 dimension ('letters', 'syllables', and 'phonemes'), p-value > 0.5
% The optimization uses the stochastic method of annealing

% Sets the random seed
setSeed(123);

% Creates a new population from the MRC database file
myPopulation = population('MRC.txt','name','myPopulation','isHeader',true,'isFormatting',true);

% Creates a new sample of 100 words that can be saved as 'mySample1.txt'
mySample1 = sample(100,'name','mySample1','outFile','mySample1.txt');

% Links the sample to the population from which its items will be drawn
mySample1.setPop(myPopulation);

% Creates a second new sample of 100 words that can be saved as 'mySample2.txt'
mySample2 = sample(100,'name','mySample2','outFile','mySample2.txt');

% Links the sample to the population from which its items will be drawn
mySample2.setPop(myPopulation);

% Creates a new SOS optimization
mySOS = sos();

% Adds the two samples to the optimization
mySOS = mySOS.addSample(mySample1);
mySOS = mySOS.addSample(mySample2);

% Adds a new constraint: maximize the difference between the samples on average 'KFfrequency'
myConstraint = mySOS.addConstraint('sosObj', mySOS, 'name','myConstraint', 'constraintType', 'soft', 'fnc', 'orderedMax', 'stat', 'mean', 'sample1', mySample1, 'sample2', mySample2, 's1ColName', 'KFfrequency', 'S2ColName', 'KFfrequency', 'exponent', 2, 'paired', false, 'weight', 1);

% Adds a new constraint: match the samples on average 'letters'
myConstraint2 = mySOS.addConstraint('sosObj', mySOS, 'name','myConstraint2','constraintType', 'soft', 'fnc', 'min', 'stat', 'mean', 'sample1', mySample1, 'sample2', mySample2, 's1ColName', 'letters', 'S2ColName', 'letters', 'exponent', 2, 'paired', false, 'weight', 1);

% Adds a new constraint: match the samples on average 'syllables'
myConstraint3 = mySOS.addConstraint('sosObj', mySOS, 'name','myConstraint3','constraintType', 'soft', 'fnc', 'min', 'stat', 'mean', 'sample1', mySample1, 'sample2', mySample2, 's1ColName', 'syllables', 'S2ColName', 'syllables', 'exponent', 2, 'paired', false, 'weight', 1);

% Adds a new constraint: match the samples on average 'phonemes'
myConstraint4 = mySOS.addConstraint('sosObj', mySOS, 'name','myConstraint4','constraintType', 'soft', 'fnc', 'min', 'stat', 'mean', 'sample1', mySample1, 'sample2', mySample2, 's1ColName', 'phonemes', 'S2ColName', 'phonemes', 'exponent', 2, 'paired', false, 'weight', 1);

% Fills the samples with items selected randomly from the population
mySOS.initFillSamples();

% Normalizes the values of dimension of interest 
mySOS.normalizeData();

% Creates an independent samples t-test; test "passes" if average 'KFfrequency' differs between the samples, p < .05 
mySOS.addttest('name','myTTest','type','independent', 'sample1', mySample1, 'sample2', mySample2, 's1ColName', 'KFfrequency', 's2ColName', 'KFfrequency', 'desiredpvalCondition', '<=', 'desiredpval', 0.05);

% Creates an independent samples t-test: test "passes" if average 'letters' is  matched between the samples, p > 0.5
mySOS.addttest('name','myTTest2','type', 'independent', 'sample1', mySample1, 'sample2', mySample2, 's1ColName', 'letters', 's2ColName', 'letters', 'desiredpvalCondition', '=>', 'desiredpval', 0.5);

% Creates an independent samples t-test: test "passes" if average 'syllables' is  matched between the samples, p > 0.5
mySOS.addttest('name','myTTest3','type', 'independent', 'sample1', mySample1, 'sample2', mySample2, 's1ColName', 'syllables', 's2ColName', 'syllables', 'desiredpvalCondition', '=>', 'desiredpval', 0.5);

% Creates an independent samples t-test: test "passes" if average 'phonemes' is  matched between the samples, p > 0.5
mySOS.addttest('name','myTTest4','type', 'independent', 'sample1', mySample1, 'sample2', mySample2, 's1ColName', 'phonemes', 's2ColName', 'phonemes', 'desiredpvalCondition', '=>', 'desiredpval', 0.5);

% Specifies the type of optimization (default: 'greedy')
mySOS.setAnnealSchedule('schedule', 'exp');

% Starts the SOS GUI
sos_gui();
